弱点 (豆瓣)
Description: 弱点电影简介和剧情介绍,弱点影评、图片、预告片、影讯、论坛、在线购票
Keywords: 弱点,The Blind Side,弱点影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.246豆瓣电影Top250

# 弱点 The Blind Side (2009)

导演: 约翰·李·汉考克
编剧: 约翰·李·汉考克 / 迈克尔·刘易斯
主演: 桑德拉·布洛克 / 蒂姆·麦格罗 / 昆东·亚伦 / 杰·海德 / 莉莉·柯林斯 / 雷·迈克金农 / 金·迪肯斯 / 安德莱内·列诺斯 / 凯西·贝茨 / 凯萨琳·戴尔 / 安迪·斯塔尔 / 汤姆·诺维茨基 / 莎朗·莫里斯 / 奥马尔·J·多尔西 / 伊劳伊·辛格尔顿 / 罗达·格里菲丝 / 艾希礼·勒孔特·坎贝尔 / Elizabeth Omilami / 阿非莫·奥米拉 / 马丽娅豪厄尔 / Patrick G. Keenan / 大卫·德怀尔 / 罗伯特·普拉尔戈 / 布雷特·赖斯 / Preston Brant / 马修·阿特金森 / 约翰·纽伯格 / 乔·克里斯特 / Phillip Fulmer / Lou Holtz / Nick Saban / Haji Abdullah / Demetrius B. Banks / Tim Brazeal / Byron Bryson / Chrissy Chambers / Monica D'Onofrio / J. Colby Doler / Roger Goodell / 杰夫科斯·格林 / 安东尼·B·哈里斯 / Scottie Knollin / Amir Kovacs / 梅丽莎·乐爱伦
类型: 剧情 / 家庭 / 传记 / 运动
制片国家/地区: 美国
语言: 英语
上映日期: 2009-11-20(美国)
片长: 129分钟
又名: 守护有心人(港) / 攻其不备(台) / 温情橄榄球 / 暗算 / 盲点
IMDb: tt0878804
豆瓣评分
引用
8.7
282894人评价
5星
48.4%
4星
40.9%
3星
9.8%
2星
0.7%
1星
0.2%
好于 97% 家庭片
好于 96% 剧情片
想看 看过
评价:
推荐

## 弱点的剧情简介 · · · · · ·

黑人男孩奥赫（昆东•亚伦 Quinton Aaron 饰）自幼父母离异，无家可归。不过，木讷的他却因为极强的身体条件和运动天赋，幸运地进入了一家私立基督教高中。虽然，他科科零分，但是一些细节却让他显得与众不同。一次排球比赛后，他主动收拾垃圾的行为，引起了陶西一家的注意。于是，陶西太太（桑德拉•布洛克 Sandra Bullock 饰）决定收养奥赫，并把他培养成橄榄球选手。陶西太太让他感受到了家庭的温暖。同时，陶西的儿子还帮助奥赫训练，使他很快地融入了橄榄球队的生活，不断激发运动的潜能。终于，在一次比赛中，他因出色的表现崭露头角，开始获得了球探的关注，随之带来了一系列的甜蜜和麻烦……
本片根据迈克尔•刘易斯（Michael Lewis）的原著《弱点：比赛进程》（The Blind Side: Evolution of the Game）改编，取材自20... (展开全部) 黑人男孩奥赫（昆东•亚伦 Quinton Aaron 饰）自幼父母离异，无家可归。不过，木讷的他却因为极强的身体条件和运动天赋，幸运地进入了一家私立基督教高中。虽然，他科科零分，但是一些细节却让他显得与众不同。一次排球比赛后，他主动收拾垃圾的行为，引起了陶西一家的注意。于是，陶西太太（桑德拉•布洛克 Sandra Bullock 饰）决定收养奥赫，并把他培养成橄榄球选手。陶西太太让他感受到了家庭的温暖。同时，陶西的儿子还帮助奥赫训练，使他很快地融入了橄榄球队的生活，不断激发运动的潜能。终于，在一次比赛中，他因出色的表现崭露头角，开始获得了球探的关注，随之带来了一系列的甜蜜和麻烦……
本片根据迈克尔•刘易斯（Michael Lewis）的原著《弱点：比赛进程》（The Blind Side: Evolution of the Game）改编，取材自2009年美国国家橄榄球联盟（National Football League）选秀状元迈克尔•奥赫的非凡经历。荣获第82届奥斯卡最佳女主角奖（Sandra Bullock）。 ©豆瓣

## 弱点的演职员 · · · · · · ( 全部 79 )

- 约翰·李·汉考克 导演
- 桑德拉·布洛克 饰 莉·安妮·陶西
- 蒂姆·麦格罗 饰 肖恩·陶西
- 昆东·亚伦 演员
- 杰·海德 饰 小肖恩陶西
- 莉莉·柯林斯 演员

## 弱点的图片 · · · · · · ( 添加视频评论 | 图片335 · 添加 )

## 弱点的获奖情况 · · · · · · ( 全部 )

- 第82届奥斯卡金像奖
- 最佳影片(提名)
- 吉尔·内特 / 安德鲁·科索夫 / 布罗德里克·约翰逊

- 第67届金球奖
- 电影类 剧情片最佳女主角
- 桑德拉·布洛克

- 第19届MTV电影奖
- MTV电影奖 最佳女演员(提名)
- 桑德拉·布洛克

## 喜欢这部电影的人也喜欢 · · · · · ·

  当幸福来敲门

  光荣之路

  百万美元宝贝

  追梦赤子心

  摔跤吧！爸爸

  荒岛余生

  雨人

  叫我第一名

  卡特教练

  国王的演讲

我要写短评

## 弱点的短评 · · · · · · ( 全部 65696 条 )

热门 / 最新 / 好友

### 784 有用 Zero-_- 看过 2009-11-26 12:32:09

太感人了，在电影院笑着哭了。 男主角演的太好了。在美国看的第九部电影。

### 4926 有用 蚂蚁没问题 看过 2010-03-13 02:15:09

一开始，老师那里我以为会有冲突，结果没有，兄弟姐妹那里我以为会有不愿意接纳他的意思，结果也没有，夫妻会因为到底要不要收留他而激烈争吵，最后居然还是没有，没有，都没有，这是一部有很多很多好人的电影，看电影都说喜欢看冲突，可是真的关心一位角色的话，我愿意看到他生活在这样的世界。

### 560 有用 十个斗的眼窝浅 看过 2010-04-09 14:21:55

我从未有过这个——一张床！

### 1279 有用 Q。 看过 2010-04-02 11:18:56

关键是你是什么人，还有就是你想成为什么样的人。ps，不管是否太美式温情励志，但他始终是真实发生并且存在着的事情。★★★★

### 789 有用 岛上的夏奈 看过 2010-06-16 04:15:32

看到一半的时候我想为这装逼温情打二星，但看到结尾发现竟然是真人真事，好吧，人性还是光辉的，四星

> 更多短评 65696条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 弱点的影评 · · · · · · ( 全部 1046 条 )

热门 / 最新 / 好友
2pthegamer 2009-12-19 12:33:26

## 【转发】Blind Side —每个人都有盲点（TDL首发）

这篇影评可能有剧透

http://www.tdl100.com/redirect.php?tid=6466&goto=lastpost Blind Side 在FOOTBALL里代表一个选手视线外的地方。 准备传球的四分卫的左手边（左撇子是右手边）。 跑锋带球的右后方（从后追上的人会瞄准你的球敲）。 外接手接球时的正后方（角卫和安全卫会对你进行狠狠撞击。... (展开)
1597 44 152回应 收起
Vespertine 2010-04-04 14:06:39

## 黑猫/白猫，还有婚变中的Sandra Bullock

记得大学学开车的时候，教练教我每次选择换线的时候的程序就是保持速度--在好的时机做出判断---打信号---the last and the most important thing:ALWAYS check the blind side（最后也是最重要的：永远要观察盲点）。 判断是一时两刻就可以做出的选择，每个人每一刻都在做判断... (展开)
482 26 33回应 收起
阿不壳 2012-04-13 23:00:07

## 保护他，而不是撞倒他

橄榄球赛里，常能看到一个抱着球的人像抱萝卜的兔子一样没命儿奔跑，一群如狼似虎的人在追赶他。追捕和拦截往往发生在带球者身后，在他看不见也无能自保的地方，有他的对手，也有他的队友；需要他有勇气，也需要他去信赖，那里叫做盲区（blind side）。 电影《The blind side... (展开)
623 11 32回应 收起
冰糖苷 2018-11-04 18:30:54

## 解构创伤与重建人生——《The Blind Side》观后感

这篇影评可能有剧透

《The blind side》是我大二时，外教在课堂上放映的。当时译作《盲点》，之后不知何故全网用了《弱点》这个翻译，在此不做市场价值判断。单从笔者观后感的角度，《盲点》确实是更好的诠释，原因何故？先从迈克这个孩子说起。 一、迈克其人——问题少年之“问题”由来 迈克是个... (展开)
332 2 46回应 收起
石壮壮 2009-12-18 17:18:53

## 人性的“弱点”

迈克尔·奥赫出生在贫困，复杂的环境，直至三岁，他不得不过起流浪汉的生活。生活选择了他，但是他已经没有勇气面对未来，只是停留在三岁前妈妈的保护。 那是一个高大壮硕、皮肤黝黑的孩子，面无表情的脸上，掩不住些许苦愁的滋味。明明天气阴冷，他却穿着单薄的T恤和短... (展开)
238 17 24回应 收起
doherty 2009-12-13 21:38:01

## 应该给Sandra Bullock一个奥斯卡提名..

The Blind Side 弱点 2009年12月10日，迪斯尼N年磨一剑企图振兴2D动画的the princess and the frog大规模上映，想必只有7百万的周五票房要令人失望了，可是榜眼位置不是大红大紫的new moon，而是取得400万刀并且上映4周已经累计票房$139,497,000的The Blind Side。 看完电... (展开)
93 24 88回应 收起
卡塞尔少年 2010-02-11 15:07:02

## 我们没有的inspirational film

本来我是要研究《律政俏佳人》《风月俏佳人》的电影语言的，因为我们没有这种标准好莱坞式轻松娱乐，到底这帮美国佬是怎么弄出这个套路，这个套路更详细的拍摄细节是什么。然后我重温了《唐伯虎点秋香》瞬间发现儿时看着好玩的电影，现在看来如此之多的符合高级电影理论，赵薇... (展开)
69 7回应 收起
心灵流沙 2019-06-12 17:23:35

## 一部令人不适的自我意淫作品

很少给一星，但看完这部电影真的是有点受不了了。看之前还很期待，本以为是百万美元宝贝那样的励志作品，结果看完感觉大失所望，引起不适。 女主角可以给黑人男主无微不至的关怀，供他吃供他穿，想开车二话不说给买，好闺蜜好心提醒防人之心不可无她二话不说跟人家绝交！临走前... (展开)
48 19 60回应 收起
尼玛 2017-07-10 08:37:30

## 弱点

直找不到什么好看的电影，要么太暴力，要么婆婆妈妈的不知道讲什么。但是今天看到了一部电影《弱点》，开始还以为是专门讲什么心理学的东西（和恐怖惊悚电影一类的）。但是这部长达两个小时的电影，一开始看了就引人入胜，时常伴随着淡淡的感动，触动你的神经，让你时不时的眼... (展开)
30 1 1回应 收起

> 更多影评 1046篇

添加新讨论

## 讨论区 · · · · · ·

Blind Side后面的真实故事和剧情大对比 | 来自壹面壹缘 | 80 回应 | 2022-11-23 01:19:11
要是黑小伙和桑德拉布洛克来一段忘年恋就有意思了... | 来自MrZongli | 39 回应 | 2022-11-07 19:39:39
为什么前250有两个《弱点》？！！…… | 来自保留一份热爱 |  | 2022-10-31 18:14:44
美国白人真他娘的伟大 | 来自coyote333 |  | 2022-10-15 15:52:50
民主党那一段什么意思呀？ | 来自放纵不羁爱自由 | 6 回应 | 2022-10-14 16:15:49

> 去这部影片的讨论区（全部169条）

## 关于《弱点》的问题 · · · · · · ( 全部10个 )

- 片尾的图片含义？ 5人回答
- 为什么女主那么讨厌田纳西的学校和球队？ 1人回答

> 全部10个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【励志电影】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 美国生活面面观 (Griet)
- 2010第十三届上海国际电影节影片介绍大全 (妖灵妖)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  刚刚 想看
- pupuさん
  1分钟前 看过
- Brenda
  6分钟前 看过

389898人看过 / 138485人想看

订阅弱点的评论:
feed: rss 2.0